@@ -163,6 +163,8 @@ from . import adapter_fastnovelnet
 from . import adapter_squidgeworldorg
 from . import adapter_novelfull
 from . import adapter_worldofxde
+from . import adapter_psychficcom
+from . import adapter_deviantartcom
 
 ## This bit of complexity allows adapters to be added by just adding
 ## importing.  It eliminates the long if/else clauses we used to need
