@@ -16,27 +16,23 @@
 #
 from __future__ import absolute_import
 
-import re
 import os.path
 import datetime
 import string
-import zipfile
 from zipfile import ZipFile, ZIP_DEFLATED
 import logging
 
 # py2 vs py3 transition
-from .. import six
-from ..six import text_type as unicode
 from ..six import ensure_text
 from ..six import ensure_binary
 from io import BytesIO
 
-from ..configurable import Configurable
-from ..htmlcleanup import removeEntities, removeAllEntities, stripHTML
+from ..requestable import Requestable
+from ..htmlcleanup import stripHTML
 
 logger = logging.getLogger(__name__)
 
-class BaseStoryWriter(Configurable):
+class BaseStoryWriter(Requestable):
 
     @staticmethod
     def getFormatName():
@@ -47,7 +43,7 @@ class BaseStoryWriter(Configurable):
         return '.bse'
 
     def __init__(self, configuration, adapter):
-        Configurable.__init__(self, configuration)
+        Requestable.__init__(self, configuration)
 
         self.adapter = adapter
         self.story = adapter.getStoryMetadataOnly() # only cache the metadata initially.
@@ -161,7 +157,12 @@ class BaseStoryWriter(Configurable):
             self._write(out,END.substitute(self.story.getAllMetadata()))
 
     # if no outstream is given, write to file.
-    def writeStory(self,outstream=None, metaonly=False, outfilename=None, forceOverwrite=False):
+    def writeStory(self,
+                   outstream=None,
+                   metaonly=False,
+                   outfilename=None,
+                   forceOverwrite=False,
+                   notification=lambda x,y:x):
 
         self.metaonly = metaonly
         if outfilename == None:
@@ -198,23 +199,18 @@ class BaseStoryWriter(Configurable):
                         logger.warning("File(%s) Updated(%s) more recently than Story(%s) - Skipping" % (outfilename,fileupdated,lastupdated))
                         return
             if not metaonly:
-                self.story = self.adapter.getStory() # get full story
-                                                     # now, just
-                                                     # before writing.
-                                                     # Fetch before
-                                                     # opening file.
+                # get full story now, just before writing.  Fetch
+                # before opening file.
+                self.story = self.adapter.getStory(notification)
             outstream = open(outfilename,"wb")
         else:
             close=False
             logger.debug("Save to stream")
 
         if not metaonly:
-            self.story = self.adapter.getStory() # get full story now,
-                                                 # just before
-                                                 # writing.  Okay if
-                                                 # double called with
-                                                 # above, it will only
-                                                 # fetch once.
+            # get full story now, just before writing.  Okay if double
+            # called with above, it will only fetch once.
+            self.story = self.adapter.getStory(notification)
         if self.getConfig('zip_output'):
             out = BytesIO()
             self.zipout = ZipFile(outstream, 'w', compression=ZIP_DEFLATED)
@@ -255,4 +251,3 @@ class BaseStoryWriter(Configurable):
 
     def writeStoryImpl(self, out):
         "Must be overriden by sub classes."
-        pass
